local lgr = love.graphics

function love.load()
	love.physics.setMeter(1) --the height of a meter our worlds will be 64px
	world = love.physics.newWorld(0, 0, true) --create a world for the bodies to exist in with horizontal gravity of 0 and vertical gravity of 9.81
	tank = createTank(world, 300,300, 64,32)
	tank2 = createTank(world, 200,200,64,32)
	
	--initial graphics setup
	love.graphics.setBackgroundColor(104, 136, 248) --set the background color to a nice blue
	love.graphics.setMode(650, 650, false, true, 0) --set the window dimensions to 650 by 650

	
end


function love.update(dt)
	world:update(dt) --this puts the world into motion

	tank.chassis.body:setAngularVelocity(0)
	tank2.chassis.body:setAngularVelocity(0)
	tank.chassis.body:setLinearVelocity(0,0)
	tank2.chassis.body:setLinearVelocity(0,0)
	
	if love.keyboard.isDown("right") then 
		tank.chassis.body:setAngularVelocity( 2 )
	elseif love.keyboard.isDown("left") then
		tank.chassis.body:setAngularVelocity( -2 )
	elseif love.keyboard.isDown("up") then
		local x,y = dirVector(tank.chassis.body:getAngle())
		tank.chassis.body:setLinearVelocity(x*20,y*20)
	elseif love.keyboard.isDown("down") then 
		tank.turret.joint:setMotorSpeed(1)
	end
end

function love.draw()
	love.graphics.setColor(50, 50, 50)
	love.graphics.polygon("fill", tank.chassis.body:getWorldPoints(tank.chassis.shape:getPoints()))
	love.graphics.setColor(150, 150, 150)
	love.graphics.polygon("fill", tank.turret.body:getWorldPoints(tank.turret.shape:getPoints()))
	
	love.graphics.setColor(255, 255, 255)
	love.graphics.polygon("fill", tank2.chassis.body:getWorldPoints(tank2.chassis.shape:getPoints()))
	
	topLeftX, topLeftY, bottomRightX, bottomRightY =  tank.chassis.fixture:getBoundingBox( index )
	love.graphics.polygon("line", topLeftX,topLeftY,bottomRightX,topLeftY,bottomRightX,bottomRightY,topLeftX,bottomRightY)

	love.graphics.circle( "fill", 100, 100, 3, 100 )
end


function dirVector(rot)
	return math.cos(rot), math.sin(rot) 
end


function createTank(world, x,y,sX,sY)
	local tank = {}
	tank.chassis = {}
	tank.chassis.body = love.physics.newBody(world,x,y,"dynamic")
	tank.chassis.shape = love.physics.newRectangleShape(sX, sY)
	tank.chassis.fixture = love.physics.newFixture(tank.chassis.body, tank.chassis.shape, 1)
	tank.chassis.fixture:setRestitution(0.1)
	
	tank.turret = {}
	tank.turret.body = love.physics.newBody(world,x,y,"dynamic")
	tank.turret.shape = love.physics.newRectangleShape(64, 16)
	tank.turret.fixture = love.physics.newFixture(tank.turret.body, tank.turret.shape, 1)
	
	tank.turret.joint = love.physics.newRevoluteJoint( tank.chassis.body, tank.turret.body, x, y, false )
	tank.turret.joint:enableMotor(true)
	tank.turret.joint:setMaxMotorTorque(1000) -- Just for shits and giggles? Why isnt this working
	tank.turret.joint:setMotorSpeed(50)
	return tank
end